#!/bin/sh

set -euo pipefail
# git fetch

CURRENTTAG=$(git tag --sort=-taggerdate | head -n 1)
PREVIOUSTAG=$(git tag --sort=-taggerdate | head -n 2 | tail -n 1)
ALLCHANGES=$(npx -y @philippdormann/changelogen@latest --from $PREVIOUSTAG --to $CURRENTTAG --no-output | sed 's/"/\\"/g' | tail -n +6)
FORMATTED_CHANGES=$(echo "# $CURRENTTAG \n $ALLCHANGES" | pandoc -f markdown -t html | sed 's/"/'"'"'/g' | xargs echo -n)


if [[ -n "$PLUGIN_GITEA_DOMAIN" ]]; then
  if [[ -z "$PLUGIN_GITEA_APIKEY"]]; then
    echo "No api key provided";
    exit 1;
  fi
  if [[ -z "$PLUGIN_REPO"]]; then
    PLUGIN_REPO=$CI_REPO_NAME
  fi

  curl --request POST \
  --url "https://$PLUGIN_GITEA_DOMAIN/api/v1/repos/$PLUGIN_REPO/releases" \
  --header "Content-Type: application/json" \
  --header "Authorization: token $PLUGIN_GITEA_APIKEY" \
  --data "{
      \"name\": \"$CURRENTTAG\",
      \"body\": \"$ALLCHANGES\",
      \"draft\": false,
      \"tag_name\": \"$CURRENTTAG\"
  }"
fi
if [[ -n "$PLUGIN_MATRIX_SERVER" ]]; then
  if [[ -z "$PLUGIN_MATRIX_USER" ]]; then
    echo "No matrix username provided";
    exit 3;
  fi
  if [[ -z "$PLUGIN_MATRIX_PASSWORD" ]]; then
    echo "No matrix password provided";
    exit 4;
  fi
  if [[ -z "$PLUGIN_MATRIX_ROOM" ]]; then
    echo "No matrix room id provided";
    exit 4;
  fi

  MATRIX_LOGIN=$(curl --request POST \
      --url "https://$PLUGIN_MATRIX_SERVER/_matrix/client/r0/login" \
      --header "Content-Type: application/json" \
      --data "{
        \"type\": \"m.login.password\",
        \"user\": \"$PLUGIN_MATRIX_USER\",
        \"password\": \"$PLUGIN_MATRIX_PASSWORD\"
      }")
  MATRIX_TOKEN=$(echo $MATRIX_LOGIN | jq .access_token | sed 's/"/\/g' )
  curl --request POST \
      --url "https://$PLUGIN_MATRIX_SERVER/_matrix/client/r0/rooms/$PLUGIN_MATRIX_ROOM/send/m.room.message?access_token=$MATRIX_TOKEN" \
      --header "Content-Type: application/json" \
      --data "{
        \"msgtype\": \"m.text\",
        \"body\": \"$(echo "# $CURRENTTAG \n $ALLCHANGES" | xargs echo -n)\",
        \"format\": \"org.matrix.custom.html\",
        \"formatted_body\": \"$FORMATTED_CHANGES\"
      }"
fi